@@ -1,12 +1,16 @@
-'''
+"""
     This is a our invoke program
-'''
+"""
+import os
+import sys
 import tornado.log
 from invoke import Program, Collection
 from . import run
 from . import db
 
-VERSION = '0.0.4'
+sys.path.insert(0, os.getcwd())
+
+VERSION = "0.0.5"
 
 _NAMESPACE_ = Collection()
 
@@ -18,6 +22,4 @@ _NAMESPACE_.add_task(db.revise)
 
 tornado.log.enable_pretty_logging()
 
-program = Program(
-    version=VERSION, namespace=_NAMESPACE_
-)  # pylint: disable=C0103
+program = Program(version=VERSION, namespace=_NAMESPACE_)  # pylint: disable=C0103
